@@ -1,5 +1,7 @@
 __all__ = ('LoanPoint', 'LoanObjectPoint', 'ClosedLoanPoint', 'ClosedLoanObjectPoint', 'LoanPaymentPoint',
-           'ExportPoint', 'PartialLoanPaymentPoint', 'ExtendLoanPoint', 'RestructureLoanPoint',)
+           'ExportPoint', 'PartialLoanPaymentPoint', 'ExtendLoanPoint', 'RestructureLoanPoint', 'ValidateLoanPoint',
+           'PublicPaymentPoint', 'CallBackPaymentPoint',
+           )
 
 from typing import OrderedDict, Union
 
@@ -171,6 +173,32 @@ class RestructureLoanReadContract(Contract):
     restructure_schedules = serializers.ListField()
 
 
+class ValidateLoanCreateContract(Contract):
+    loan_id = serializers.IntegerField(min_value=1)
+
+
+class ValidateLoanResponseContract(Contract):
+    loan_id = serializers.IntegerField(min_value=1)
+    user_id = serializers.IntegerField(min_value=0)
+
+
+class PublicPaymentCreateContract(Contract):
+    loan_id = serializers.IntegerField(min_value=1)
+    ip = serializers.IPAddressField()
+    cryptogram = serializers.CharField(max_length=2048)
+    payment_amount = serializers.DecimalField(max_digits=16, decimal_places=0)
+
+
+class CallBackPaymentCreateContract(Contract):
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
+    bank_card_payment_id = serializers.IntegerField()
+
+
+class CallBackPaymentResponseContract(Contract):
+    id = serializers.IntegerField()
+    type = serializers.CharField(max_length=32)
+
+
 class RestructureLoanID(ID):
     _service = SERVICE
     _app = 'loans'
@@ -213,6 +241,24 @@ class PartialPaymentID(ID):
     _view_set = 'partial_payment'
 
 
+class ValidateLoanID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'validate_loan'
+
+
+class PublicPaymentID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'public_payment'
+
+
+class CallBackPaymentID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'call_back_payment'
+
+
 class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = LoanID()
     _read_contract = LoanReadContract
@@ -267,3 +313,22 @@ class RestructureLoanPoint(CreatePointMixin, ListPointMixin, ContractPoint):
     _point_id = RestructureLoanID()
     _create_contract = RestructureLoanCreateContract
     _read_contract = RestructureLoanReadContract
+
+
+class ValidateLoanPoint(CreatePointMixin, ResponseMixin, ContractPoint):
+    _point_id = ValidateLoanID()
+    _create_contract = ValidateLoanCreateContract
+    _response_contract = ValidateLoanResponseContract
+
+
+class PublicPaymentPoint(CreatePointMixin, ContractPoint):
+    _point_id = PublicPaymentID()
+    _create_contract = PublicPaymentCreateContract
+
+
+class CallBackPaymentPoint(CreatePointMixin, ResponseMixin, ContractPoint):
+    _point_id = CallBackPaymentID()
+    _create_contract = CallBackPaymentCreateContract
+    _response_contract = CallBackPaymentResponseContract
+
+
