@@ -58,7 +58,7 @@ class ResendSmsSignCreateContract(Contract):
 
 class OrderUserIdsContract(Contract):
     id = serializers.IntegerField(min_value=1)
-    user_id = serializers.IntegerField(max_length=8)
+    user_id = serializers.IntegerField()
 
 
 class OrderID(ID):
