@@ -1,4 +1,4 @@
-__all__ = ('BankCardPaymentPoint',)
+__all__ = ('BankCardPaymentPoint', 'PublicBankCardPaymentPoint')
 
 from expressmoney.api import *
 
@@ -14,7 +14,7 @@ class BankCardPaymentCreateContract(Contract):
 
 
 class PaymentInvoiceCreateContract(Contract):
-    amount = serializers.DecimalField(max_digits=16, decimal_places=2)
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
     user_id = serializers.IntegerField(min_value=1)
     loan_type = serializers.CharField(max_length=16)
     description = serializers.CharField(max_length=512)
@@ -36,6 +36,20 @@ class BankCardPaymentReadContract(BankCardPaymentCreateContract):
     created = serializers.DateTimeField()
 
 
+class PublicBankCardPaymentCreateContract(Contract):
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0, min_value=1)
+    ip = serializers.CharField(max_length=32)
+    withdraw = serializers.BooleanField()
+    order_id = serializers.IntegerField()
+    order_type = serializers.CharField(max_length=128)
+    cryptogram = serializers.CharField(max_length=2048)
+
+
+class PublicBankCardPaymentResponseContract(Contract):
+    id = serializers.IntegerField(min_value=1)
+    created = serializers.DateTimeField()
+
+
 class BankCardPaymentID(ID):
     _service = SERVICE
     _app = 'payments'
@@ -48,6 +62,12 @@ class PaymentInvoiceID(ID):
     _view_set = 'payment_invoice'
 
 
+class PublicBankCardPaymentID(ID):
+    _service = SERVICE
+    _app = 'payments'
+    _view_set = 'bank_card_public_payment'
+
+
 class BankCardPaymentPoint(ListPointMixin, ResponseMixin, CreatePointMixin, ContractPoint):
     _point_id = BankCardPaymentID()
     _create_contract = BankCardPaymentCreateContract
@@ -59,3 +79,9 @@ class PaymentInvoicePoint(CreatePointMixin, ResponseMixin, ContractPoint):
     _point_id = PaymentInvoiceID()
     _create_contract = PaymentInvoiceCreateContract
     _response_contract = PaymentInvoiceResponseContract
+
+
+class PublicBankCardPaymentPoint(ResponseMixin, CreatePointMixin, ContractPoint):
+    _point_id = PublicBankCardPaymentID()
+    _create_contract = PublicBankCardPaymentCreateContract
+    _response_contract = PublicBankCardPaymentResponseContract
